@@ -1,15 +1,14 @@
-from .set import SetConfig
-from .print import Printer
-from .list import ListResource
+from .pycritty import SetConfig
+from .ls import ListResource
 from .save import SaveConfig
 from .load import LoadConfig
 from .install import Install
+from .rm import Remove
 
 subcommands = {
-    'set': SetConfig,
-    'print': Printer,
-    'list': ListResource,
+    'ls': ListResource,
     'save': SaveConfig,
     'load': LoadConfig,
     'install': Install,
+    'rm': Remove,
 }
